pub enum MachineBundleConversionError {
GlobalImport(ImportError),
LocalImport {
role: String,
source: ImportError,
},
}Expand description
Errors that can occur while converting an exported bridge bundle into a machine bundle.
Variants
GlobalImport(ImportError)
Global type JSON could not be parsed back into a Rust type.
LocalImport
One of the local type JSON payloads could not be parsed.
Fields

source: ImportErrorUnderlying import error.